## DESCRIPTION

Recipe secrets module allows the use of secrets in configuration files imported from a recipe. It retrieves secret values from a .env file, ensuring sensitive data remains secure and separate from the exported configuration. This improves security and flexibility by preventing hardcoded credentials in configuration management.

Features
- Automatically replaces placeholders in configuration files with values from a .env file.
- Load different secrets for different environments without modifying configuration files.
- Works within the configuration import process to apply secrets dynamically.

## INSTALLATION

Install as you would normally install a contributed Drupal module.\
See: https://www.drupal.org/node/895232 for further information.

## Usage

### 1. Enable the Module in Your Recipe
Ensure that the **Recipe Secrets** module is activated in your recipe before importing configurations.

### 2. Define Secrets in the `.env` File
Create or update your `.env` file with the required secret values.

#### Example `.env` file:
```ini
API_KEY=your-api-key-here
DB_PASSWORD=your-secure-password
```

### 3. Reference Secrets in Your Configuration Files
Use the `!secret` syntax to reference secrets in your YAML configuration files.  
The module will automatically replace these references with values from the `.env` file during the import process.

#### Example YAML Configuration File:
```yaml
api.settings:
  api_key: !secret {{API_KEY}}

database:
  password: !secret {{DB_PASSWORD}}
```

## MAINTAINERS

Current maintainers:

- ALEXIS MARTINEZ MARTINEZ - https://www.drupal.org/u/alexismmd