<?php

declare(strict_types=1);

namespace Drupal\recipe_secrets\EventSubscriber;

use Drupal\Core\Config\ConfigCrudEvent;
use Drupal\Core\Config\ConfigEvents;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Updates the configuration data replacing data.
 */
final class RecipeSecretsSubscriber implements EventSubscriberInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events[ConfigEvents::SAVE][] = ['onConfigSave'];
    return $events;
  }

  /**
   * The storage is transformed for importing.
   *
   * @param \Drupal\Core\Config\ConfigCrudEvent $event
   *   The config storage transform event.
   */
  public function onConfigSave(ConfigCrudEvent $event) {
    $data = $event->getConfig()->getRawData();
    $data_values = static::getKeysAndValues($data);
    $modified = FALSE;
    foreach ($data_values as $key => $value) {
      if (strpos($value, '!secret') !== FALSE) {
        $data_value = $event->getConfig()->get($key);
        $new_value = preg_replace_callback('/!secret {{(.*?)}}/', function ($matches) {
          return getenv($matches[1]) ?: str_replace("!secret", "", $matches[0]);
        }, $data_value);
        $event->getConfig()->set($key, trim($new_value));
        $modified = TRUE;
      }
      if ($modified) {
        $event->getConfig()->save();
      }
    }
  }

  /**
   * Helper recursive function to get keys and values from config files.
   *
   * @param array $array
   *   The raw config object.
   * @param string $prefix
   *   The key values prefix.
   *
   * @return array
   *   The result of key and values from config.
   */
  private static function getKeysAndValues($array, $prefix = ''): array {
    $result = [];
    foreach ($array as $key => $value) {
      $fullKey = $prefix ? "$prefix.$key" : $key;
      if (is_array($value)) {
        $result = array_merge($result, static::getKeysAndValues($value, $fullKey));
      }
      else {
        $result[$fullKey] = (string) $value;
      }
    }
    return $result;
  }

}
